/* ncdu - NCurses Disk Usage 
    
  Copyright (c) 2007 Yoran Heling

  Permission is hereby granted, free of charge, to any person obtaining
  a copy of this software and associated documentation files (the
  "Software"), to deal in the Software without restriction, including
  without limitation the rights to use, copy, modify, merge, publish,
  distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to
  the following conditions:
  
  The above copyright notice and this permission notice shall be included
  in all copies or substantial portions of the Software.
  
  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
  TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/


#include "config.h"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <limits.h>
#include <errno.h>

#include <curses.h>
#include <form.h>
#include <menu.h>

#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/time.h>
#include <dirent.h>

#ifndef PATH_MAX
#define PATH_MAX 4096
#endif


/*
 * GLOBAL FLAGS
 */
/* File Flags (struct dir -> flags) */
#define FF_DIR    1
#define FF_FILE   2
#define FF_OTHER  4
#define FF_ERR    8
#define FF_OTHFS 16
#define FF_SERR  32 /* error in subdirectory */

/* Settings Flags (int sflags) */
#define SF_SMFS   1 /* same filesystem */
#define SF_AS     2 /* apparent sizes */
#define SF_SI     4 /* use powers of 1000 instead of 1024 */

/* Browse Flags (int bflags) */
#define BF_NAME   1
#define BF_SIZE   2
#define BF_FILES  4
#define BF_DIRS   8
#define BF_NDIRF 32 /* Normally, dirs before files, setting this disables it */
#define BF_DESC  64
#define BF_HIDE 128 /* don't show hidden files... doesn't have anything to do with sorting though */


/*
 * STRUCTURES
 */
struct dir {
  struct dir *parent, *next, *prev, *sub;
  char *name;
  off_t size;
  unsigned int files, dirs, flags;
};


/*
 * GLOBAL VARIABLES
 *  (all defined in main.c)
 */
/* main directory data */
extern struct dir dat;
/* updated when window is resized */
extern int winrows, wincols;
/* global settings */
extern char sdir[PATH_MAX];
extern int sflags, bflags;


/*
 * GLOBAL FUNCTIONS
 */
/* util.c */
extern char *cropdir(const char *, int);
extern char *cropsize(const off_t);
/* settings.c */
extern int settingsCli(int, char **);
extern int settingsWin(void);
/* calc.c */
extern int calcUsage();
/* browser.c */
extern void showBrowser(void);
